@@ -1,14 +1,14 @@
 ;;; helm-gtags.el --- GNU GLOBAL helm interface -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2016 by Syohei YOSHIDA
-;; Copyright (C) 2020-2024 Shen, Jen-Chieh
+;; Copyright (C) 2020-2026 Shen, Jen-Chieh
 
 ;; Author: Syohei YOSHIDA <syohex@gmail.com>
 ;; Maintainer: Jen-Chieh Shen <jcs090218@gmail.com>
 ;; URL: https://github.com/syohex/emacs-helm-gtags
-;; Package-Version: 20240925.755
-;; Package-Revision: f51eec4a39d7
-;; Package-Requires: ((emacs "24.4") (helm "2.0"))
+;; Package-Version: 20260204.1753
+;; Package-Revision: bfafd3d4a7f0
+;; Package-Requires: ((emacs "27.1") (helm "3.0"))
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -66,6 +66,14 @@
   "GNU GLOBAL for helm."
   :group 'helm)
 
+;; Declare obsolete variable aliases before their referents
+(define-obsolete-variable-alias
+  'helm-c-gtags-path-style 'helm-gtags-path-style "0.8")
+(define-obsolete-variable-alias
+  'helm-c-gtags-ignore-case 'helm-gtags-ignore-case "0.8")
+(define-obsolete-variable-alias
+  'helm-c-gtags-read-only 'helm-gtags-read-only "0.8")
+
 (defcustom helm-gtags-path-style 'root
   "Style of file path."
   :type '(choice (const :tag "Root of the current project" root)
@@ -108,8 +116,8 @@
   :group 'helm-gtags)
 
 (defcustom helm-gtags-update-interval-second 60
-  "Tags are updated in `after-save-hook' if this seconds is passed from \
-last update.
+  "Update interval in seconds for tags in `after-save-hook'.
+Tags are updated if this many seconds have passed since last update.
 Always update if value of this variable is nil."
   :type '(choice (integer :tag "Update interval seconds")
                  (boolean :tag "Update every time" nil))
@@ -199,20 +207,7 @@ Always update if value of this variable is nil."
   "\\`\\s-*#\\(?:include\\|import\\)\\s-*[\"<]\\(?:[./]*\\)?\\(.*?\\)[\">]"
   "Not documented.")
 
-(defmacro helm-declare-obsolete-variable (old new version)
-  "Not documented, OLD, NEW, VERSION."
-  `(progn
-     (defvaralias ,old ,new)
-     (make-obsolete-variable ,old ,new ,version)))
-
-(helm-declare-obsolete-variable
- 'helm-c-gtags-path-style 'helm-gtags-path-style "0.8")
-(helm-declare-obsolete-variable
- 'helm-c-gtags-ignore-case 'helm-gtags-ignore-case  "0.8")
-(helm-declare-obsolete-variable
- 'helm-c-gtags-read-only 'helm-gtags-read-only "0.8")
-
-;; completsion function for completing-read.
+;; completion function for completing-read.
 (defun helm-gtags--completing-gtags (string predicate code)
   (helm-gtags--complete 'tag string predicate code))
 (defun helm-gtags--completing-pattern (string predicate code)
@@ -576,7 +571,7 @@ Always update if value of this variable is nil."
 (defun helm-gtags--construct-command (type &optional in)
   "Not documented."
   (setq helm-gtags--local-directory nil)
-  (let ((dir (helm-attr 'helm-gtags-base-directory (helm-get-current-source))))
+  (let ((dir (helm-get-attr 'helm-gtags-base-directory (helm-get-current-source))))
     (when (and dir (not (eq type 'find-file)))
       (setq helm-gtags--local-directory dir)))
   (let ((input (or in helm-gtags--query))
@@ -1172,9 +1167,9 @@ Always update if value of this variable is nil."
     (when tagname
       (setq helm-gtags--query tagname))
     (let ((tagroot (helm-gtags--find-tag-simple)))
-      (helm-attrset 'helm-gtags-base-directory dir src)
+      (helm-set-attr 'helm-gtags-base-directory dir src)
       (when tagname
-        (helm-attrset 'name (format "%s in %s" tagname (or dir tagroot)) src))
+        (helm-set-attr 'name (format "%s in %s" tagname (or dir tagroot)) src))
       (helm :sources srcs :buffer helm-gtags--buffer
             :preselect preselect-regexp))))
 
@@ -1200,7 +1195,8 @@ Always update if value of this variable is nil."
           (progn
             (fit-window-to-buffer win)
             (when (yes-or-no-p "Remove GNU Global tag files? ")
-              (with-demoted-errors (mapc #'delete-file files))))
+              (with-demoted-errors "Error deleting files: %S"
+                (mapc #'delete-file files))))
         (when (window-live-p win)
           (quit-window t win))))))
 
@@ -1323,7 +1319,7 @@ You can jump definitions of functions, symbols in this file."
   (helm-gtags--save-current-context)
   (setq helm-gtags--use-otherwin (helm-gtags--using-other-window-p))
   (helm-gtags--set-parsed-file)
-  (helm-attrset 'name
+  (helm-set-attr 'name
                 (format "Parsed File: %s"
                         (file-relative-name helm-gtags--parsed-file
                                             helm-gtags--tag-location))
@@ -1353,8 +1349,8 @@ You can jump definitions of functions, symbols in this file."
 (defun helm-gtags-show-stack ()
   "Show current context stack."
   (interactive)
-  (helm-other-buffer 'helm-source-gtags-show-stack
-                     (get-buffer-create helm-gtags--buffer)))
+  (helm :sources 'helm-source-gtags-show-stack
+        :buffer (get-buffer-create helm-gtags--buffer)))
 
 ;;;###autoload
 (defun helm-gtags-clear-stack ()
@@ -1450,8 +1446,8 @@ Generate new TAG file in selected directory with `C-u C-u'"
 (defvar helm-gtags-mode-map (make-sparse-keymap))
 
 ;;;###autoload
-(define-minor-mode helm-gtags-mode ()
-  "Enable helm-gtags"
+(define-minor-mode helm-gtags-mode
+  "Enable helm-gtags."
   :init-value nil
   :global     nil
   :keymap     helm-gtags-mode-map
